summaryrefslogtreecommitdiff
path: root/TAO/tests/Bug_1551_Regression/run_test.pl
diff options
context:
space:
mode:
Diffstat (limited to 'TAO/tests/Bug_1551_Regression/run_test.pl')
-rwxr-xr-xTAO/tests/Bug_1551_Regression/run_test.pl2
1 files changed, 1 insertions, 1 deletions
diff --git a/TAO/tests/Bug_1551_Regression/run_test.pl b/TAO/tests/Bug_1551_Regression/run_test.pl
index 2294ab98d89..e20eec9cb60 100755
--- a/TAO/tests/Bug_1551_Regression/run_test.pl
+++ b/TAO/tests/Bug_1551_Regression/run_test.pl
@@ -20,7 +20,7 @@ local $start_time = time();
local $max_running_time = 600; # 10 minutes
local $elapsed = time() - $start_time;
-local $ntimes = 300 ; # run test for 300 times
+local $ntimes = 100 ; # run test for 100 times
local $n = 0;
while($n < $ntimes) {